==> drop_account-2.3.1.tar.gz: drop_account/l10n/ar.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) حذفوا حساباتهم",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) حذفوا حساباتهم",
    "%1$s deleted their account" : "%1$s حذفوا حساباتهم",
    "An user <strong>deleted</strong> its account" : "<strong>حذف</strong> مستخدم حسابه",
    "User-Session unexpectedly expired" : "انتهت صلاحية جلسة المستخدم بشكل غير متوقع",
    "Successfully sent email" : "تم إرسال البريد الإلكتروني",
    "You have no email set up into your account" : "ليس لديك أَيُّ بريد إلكتروني مُعَد في حسابك",
    "Unexpected error sending email. Please contact your administrator." : "خطأ غير متوقع في إرسال البريد الإلكتروني. الرجاء الاتصال بالمسؤول الخاص بك.",
    "Confirm your account deletion on %s" : "قُم بتأكيد حذف حسابك على %s",
    "Account deletion confirmation for %s" : "تأكيد حذف الحساب لـ%s",
    "Hello," : "مرحباً،",
    "Someone - probably you - asked to delete their account on %s." : "شخص ما - على الأغلب أنت - طلب بحذف حسابه على %s.",
    "To confirm the account deletion, you may click on the button below." : "لتأكيد حذف الحساب، يُمكنك الضغط على الزر أدناه.",
    "Delete account" : "حذف الحساب",
    "Cheers!" : "في صحتك!",
    "User account deletion" : "حذف حساب المستخدم",
    "An app to allow users to delete their accounts." : "تطبيق يسمح للمستخدمين بحذف حساباتهم.",
    "# Description\n\nThis app allows users to delete their accounts by removing all their data.\n\nIt can also send activities to the admins about deleted accounts." : "# الوصف\n\nهذا التطبيق يسمح للمستخدمين بحذف حساباتهم عن طريق حذف كل بياناتهم.\n\nيُمكنه أيضاً إرسال أنشطة إلى المسؤولين حول الحسابات المحذوفة.",
    "Account deletion" : "حذف الحساب",
    "Allows users to delete themselves their own account." : "يسمح للمستخدمين بحذف حساباتهم الخاصة بأنفسهم.",
    "Email confirmation" : "تأكيد البريد الإلكتروني",
    "Require confirmation by email" : "طلب التأكيد عبر البريد الإلكتروني",
    "Will require users to click a confirmation link sent by email to confirm their action." : "سيتطلب من المستخدمين النقر فوق رابط تأكيد مُرسل عبر البريد الإلكتروني لتأكيد الإجراء.",
    "Data purge" : "تطهير البيانات",
    "Users are not removed right away but disabled until a background job removed their data for good. In the meanwhile, admins can \"save\" users by enabling them back." : "لا تتم إزالة المستخدمين على الفور ولكن يتم تعطيلهم حتى تزيل وظيفة خلفية بياناتهم نهائيًا، في غضون ذلك يمكن للمسؤولين \"حفظ\" المستخدمين عن طريق تمكينهم مرة أخرى.",
    "Purge user data as soon as possible." : "تطهير بيانات المستخدم في أسرع وقت ممكن."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 ? 4 : 5;");

==> drop_account-2.4.0.tar.gz: drop_account/l10n/ar.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) حذفوا حساباتهم",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) حذفوا حساباتهم",
    "%1$s deleted their account" : "%1$s حذفوا حساباتهم",
    "A user <strong>deleted</strong> its account" : "<strong>حذف</strong> مستخدم حسابه",
    "User-Session unexpectedly expired" : "انتهت صلاحية جلسة المستخدم بشكل غير متوقع",
    "Successfully sent email" : "تم إرسال البريد الإلكتروني",
    "You have no email set up into your account" : "ليس لديك أَيُّ بريد إلكتروني مُعَد في حسابك",
    "Unexpected error sending email. Please contact your administrator." : "خطأ غير متوقع في إرسال البريد الإلكتروني. الرجاء الاتصال بالمسؤول الخاص بك.",
    "Confirm your account deletion on %s" : "قُم بتأكيد حذف حسابك على %s",
    "Account deletion confirmation for %s" : "تأكيد حذف الحساب لـ%s",
    "Hello," : "مرحباً،",
    "Someone - probably you - asked to delete their account on %s." : "شخص ما - على الأغلب أنت - طلب بحذف حسابه على %s.",
    "To confirm the account deletion, you may click on the button below." : "لتأكيد حذف الحساب، يُمكنك الضغط على الزر أدناه.",
    "Delete account" : "حذف الحساب",
    "Cheers!" : "في صحتك!",
    "Account deletion on %s scheduled" : "حذف الحساب",
    "Account on %s deleted" : "حذف الحساب",
    "User account deletion" : "حذف حساب المستخدم",
    "An app to allow users to delete their accounts." : "تطبيق يسمح للمستخدمين بحذف حساباتهم.",
    "# Description\n\nThis app allows users to delete their accounts by removing all their data.\n\nIt can also send activities to the admins about deleted accounts." : "# الوصف\n\nهذا التطبيق يسمح للمستخدمين بحذف حساباتهم عن طريق حذف كل بياناتهم.\n\nيُمكنه أيضاً إرسال أنشطة إلى المسؤولين حول الحسابات المحذوفة.",
    "Account deletion" : "حذف الحساب",
    "Allows users to delete themselves their own account." : "يسمح للمستخدمين بحذف حساباتهم الخاصة بأنفسهم.",
    "Email confirmation" : "تأكيد البريد الإلكتروني",
    "Require confirmation by email" : "طلب التأكيد عبر البريد الإلكتروني",
    "Will require users to click a confirmation link sent by email to confirm their action." : "سيتطلب من المستخدمين النقر فوق رابط تأكيد مُرسل عبر البريد الإلكتروني لتأكيد الإجراء.",
    "Data purge" : "تطهير البيانات",
    "Users are not removed right away but disabled until a background job removes their data for good. In the meanwhile, admins can \"save\" users by enabling them back." : "لا تتم إزالة المستخدمين على الفور ولكن يتم تعطيلهم حتى تزيل وظيفة خلفية بياناتهم نهائيًا، في غضون ذلك يمكن للمسؤولين \"حفظ\" المستخدمين عن طريق تمكينهم مرة أخرى.",
    "Purge user data as soon as possible." : "تطهير بيانات المستخدم في أسرع وقت ممكن."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 ? 4 : 5;");
